@@ -43,13 +43,12 @@ require AutoLoader;
       ConfigureError FatalErrorException
     );
 
-$VERSION = '6.9.10';
+$VERSION = '7.07';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
     # XS function.  If a constant is not found then control is passed
     # to the AUTOLOAD in AutoLoader.
-    no warnings;
 
     my $constname;
     ($constname = $AUTOLOAD) =~ s/.*:://;
@@ -123,7 +122,7 @@ It was originally developed to be used by CGI scripts for Web pages.
 
 A web page has been set up for this extension. See:
 
-	 file:///usr/share/doc/ImageMagick-6/www/perl-magick.html@EXTRA_DOC_DIR@
+	 file:///usr/share/doc/ImageMagick-7/www/perl-magick.html
 	 http://www.imagemagick.org/script/perl-magick.php
 
 If you have problems, go to
